OC.L10N.register(
    "core",
    {
    "Please select a file." : "Kérjük, válasszon ki egy fájlt.",
    "File is too big" : "A fájl túl nagy",
    "Invalid file provided" : "Érvénytelen fájl van megadva",
    "No image or file provided" : "Nincs kép vagy fájl megadva",
    "Unknown filetype" : "Ismeretlen fájltípus",
    "Invalid image" : "Hibás kép",
    "An error occurred. Please contact your admin." : "Hiba történt. Kérjük lépjen kapcsolatba a rendszergazdával.",
    "No temporary profile picture available, try again" : "Az átmeneti profilkép nem elérhető, próbálja újra",
    "No crop data provided" : "Vágáshoz nincs adat megadva",
    "No valid crop data provided" : "Nem lett valós levágási adat megadva",
    "Crop is not square" : "Levágás nem négyzet alakú",
    "Couldn't reset password because the token is invalid" : "Nem lehet a jelszót törölni, mert a token érvénytelen.",
    "Couldn't reset password because the token is expired" : "Nem lehet a jelszót törölni, mert a token lejárt.",
    "%s password reset" : "%s jelszó visszaállítás",
    "Couldn't send reset email. Please contact your administrator." : "Visszaállítási e-mail nem küldhető. Kérjük, lépjen kapcsolatba a rendszergazdával.",
    "Couldn't send mail to following users: %s " : "Nem sikerült e-mailt küldeni a következő felhasználóknak: %s",
    "Preparing update" : "Felkészülés a frissítésre",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Javítási figyelmeztetés:",
    "Repair error: " : "Javítás hiba:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Kérjük, a frissítéshez a parancssort használja, mert az automatikus frissítés ki van kapcsolva a config.php-ban.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tábla ellenőrzése: %s",
    "Turned on maintenance mode" : "A karbantartási mód bekapcsolva",
    "Turned off maintenance mode" : "A karbantartási mód kikapcsolva",
    "Maintenance mode is kept active" : "Karbantartási mód aktiválva maradt",
    "Updating database schema" : "Adatbázis séma frissítése",
    "Updated database" : "Adatbázis frissítve",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Annak ellenőrzése, hogy az adatbázis sémát lehet-e frissíteni (ez hosszabb ideig is eltarthat az adatbázis méretétől függően)",
    "Checked database schema update" : "Az adatbázis séma frissítését ellenőriztük",
    "Checking updates of apps" : "Alkalmazások frissítésének ellenőrzése",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Annak ellenőrzése, hogy a(z) %s adatbázis sémáját lehet-e frissíteni (ez hosszabb ideig is eltarthat az adatbázis méretétől függően)",
    "Checked database schema update for apps" : "Az adatbázis séma frissítését ellenőriztük az alkalmazásokra vontakozóan",
    "Updated \"%s\" to %s" : "\"%s\" frissítve erre: %s",
    "Set log level to debug" : "Naplózási szint beállítása hibakeresésre",
    "Reset log level" : "Naplózási szint visszaállítása",
    "Starting code integrity check" : "Kódintegritás ellenőrzés elindítása",
    "Finished code integrity check" : "Kódintegritás ellenőrzés befejezve!",
    "%s (3rdparty)" : "%s (harmadik fél által)",
    "%s (incompatible)" : "%s (nem kompatibilis)",
    "Following apps have been disabled: %s" : "A következő alkalmazások le lettek tiltva: %s",
    "Already up to date" : "Már a legfrissebb változat",
    "Sunday" : "vasárnap",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Sun." : "V.",
    "Mon." : "H.",
    "Tue." : "K.",
    "Wed." : "Sze.",
    "Thu." : "Cs.",
    "Fri." : "P.",
    "Sat." : "Szo.",
    "Su" : "Va",
    "Mo" : "Hé",
    "Tu" : "Ke",
    "We" : "Sze",
    "Th" : "Cs",
    "Fr" : "Pé",
    "Sa" : "Szo",
    "January" : "január",
    "February" : "február",
    "March" : "március",
    "April" : "április",
    "May" : "május",
    "June" : "június",
    "July" : "július",
    "August" : "augusztus",
    "September" : "szeptember",
    "October" : "október",
    "November" : "november",
    "December" : "december",
    "Jan." : "jan.",
    "Feb." : "feb.",
    "Mar." : "márc.",
    "Apr." : "ápr.",
    "May." : "máj.",
    "Jun." : "jún.",
    "Jul." : "júl.",
    "Aug." : "aug.",
    "Sep." : "szept.",
    "Oct." : "okt.",
    "Nov." : "nov.",
    "Dec." : "dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Problémák vannak a kódintegritás ellenőrzéssel. Bővebb információ…</a>",
    "Settings" : "Beállítások",
    "Problem loading page, reloading in 5 seconds" : "Probléma adódott az oldal betöltése közben, újratöltés 5 másodpercen belül",
    "Saving..." : "Mentés...",
    "Dismiss" : "Elutasít",
    "seconds ago" : "pár másodperce",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A jelszó felülírásához a linket e-mailben elküldtük. Ha a levél elfogadható időn belül nem érkezik meg, ellenőrizze a spam/levélszemét mappát.<br>Ha nincs ott, kérdezze meg a helyi rendszergazdát.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Az Ön állományai titkosítva vannak. Ha nem engedélyezte korábban az adatok visszanyeréséhez szükséges kulcs használatát, akkor a jelszó megváltoztatását követően nem fog hozzáférni az adataihoz. Ha nem biztos abban, hogy mit kellene tennie, akkor kérdezze meg a rendszergazdát, mielőtt továbbmenne.<br />Biztos, hogy folytatni kívánja?",
    "I know what I'm doing" : "Tudom mit csinálok.",
    "Password can not be changed. Please contact your administrator." : "A jelszót nem lehet visszaállítani. Kérjük, lépjen kapcsolatba a redszergazdával.",
    "No" : "Nem",
    "Yes" : "Igen",
    "Choose" : "Válasszon",
    "Error loading file picker template: {error}" : "Nem sikerült betölteni a fájlkiválasztó sablont: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Nem sikerült betölteni az üzenet sablont: {error}",
    "read-only" : "csak olvasható",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fájl ütközik","{count} fájl ütközik"],
    "One file conflict" : "Egy fájl ütközik",
    "New Files" : "Új fájlok",
    "Already existing files" : "A fájlok már léteznek",
    "Which files do you want to keep?" : "Melyik fájlokat akarja megtartani?",
    "If you select both versions, the copied file will have a number added to its name." : "Ha mindkét verziót kiválasztja, a másolt fájlok neve sorszámozva lesz.",
    "Cancel" : "Mégsem",
    "Continue" : "Folytatás",
    "(all selected)" : "(összes kiválasztva)",
    "({count} selected)" : "({count} kiválasztva)",
    "Error loading file exists template" : "Hiba a létezőfájl-sablon betöltésekor",
    "Very weak password" : "Nagyon gyenge jelszó",
    "Weak password" : "Gyenge jelszó",
    "So-so password" : "Nem túl jó jelszó",
    "Good password" : "Jó jelszó",
    "Strong password" : "Erős jelszó",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "A webszerver nincs megfelelően beállítva a fájl szinkronizációhoz, mert a WebDAV interfész nem működik.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "A webszerver nincs jól beállítva, hogy kiszolgálja a(z) „{url}” hivatkozást. Bővebb információt a <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentációban</a> találhat.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Ennek a szervernek nincs működő internet kapcsolata. Ez azt jelenti, hogy néhány tulajdonság, mint pl. külső tárolók felcsatolása, frissítési értesítések, vagy egyéb alkalmazások nem működnek. A fájlok távoli elérése és az e-mail értesítések is lehet, hogy nem működnek. Ajánlott az internet kapcsolat engedélyezése a szerveren, ha minden tulajdonságot használni szeretne.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nincs memória gyorsítótár beállítva. A teljesítmény növelése érdekében kérjük állítsa be a memcache-t, ha elérhető. Bővebb információt a <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentációban</a> találhat.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom nem olvasható a PHP számára, mely nagy biztonsági probléma. Bővebb információt a <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentációban</a> találhat.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Jelenleg {version} PHP verziót használ. Javasoljuk, hogy frissítse a PHP verziót, hogy kihasználhassa a <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">teljesítménybeli és a biztonságbeli előnyöket, amiket a PHP csoport kínál</a>, amilyen hamar a disztribúciója támogatja.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "A fordított proxy fejlécek konfigurációs beállításai helytelenek, vagy egy megbízható proxy-ból próbálja az ownCloud-ot elérni. Ha nem megbízható proxy-ból próbálja elérni az ownCloud-ot, akkor ez egy biztonsági probléma, a támadó az ownCloud számára látható IP cím csalást tud végrehajtani. Bővebb információt a <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentációban</a> találhat.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached be van konfigurálva gyorsítótárnak, de rossz \"memcache\" PHP modul van telepítve. \\OC\\Memcache\\Memcached csak a \"memcached\"-t támogatja,  és nem a \"memcache\"-t. Kérjük, nézze meg a <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki oldalt a modulokkal kapcsolatban</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Néhány fájl nem felelt meg az integritás ellenőrzésen. Bővebb információt a <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentációban</a> találhat. (<a href=\"{codeIntegrityDownloadEndpoint}\">Érvénytelen fájlok listája…</a> / <a href=\"{rescanEndpoint}\">Újra ellenőrzés…</a>)",
    "Error occurred while checking server setup" : "Hiba történt a szerver beállítások ellenőrzése közben",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Az adat könyvtára és a fájljai valószínűleg elérhetőek az internetről, mert a .htaccess fájl nem működik. Erősen ajánlott, hogy úgy állítsa be a webszerverét, hogy az adatkönyvtár ne legyen elérhető az internetről, vagy mozgassa ki az adatokat a webszerver gyökérkönyvtárából.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "A \"{header}\" HTTP fejléc nincs beállítva, hogy megegyezzen az elvárttal \"{expected}\". Ez egy potenciális biztonsági kockázat és kérjük, hogy változtassa meg a beállításokat.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "A \"Strict-Transport-Security\" HTTP fejléc nincs beállítva hogy \"{seconds}\" másodpercig tartson. Biztonsági okokból ajánljuk, hogy engedélyezze a HSTS, ahogyan ezt részletezzük a <a href=\"{docUrl}\" rel=\"noreferrer\">biztonsági tippek</a> dokumentációban.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Jelenleg HTTP-vel éri el a weboldalt. Erősen ajánlott a HTTPS konfiguráció használata ehelyett, ahogyan ezt részleteztük a <a href=\"{docUrl}\">biztonsági tippek</a> dokumentációban",
    "Shared" : "Megosztott",
    "Shared with {recipients}" : "Megosztva ővelük: {recipients}",
    "Error" : "Hiba",
    "Error while sharing" : "Nem sikerült létrehozni a megosztást",
    "Error while unsharing" : "Nem sikerült visszavonni a megosztást",
    "The public link will expire no later than {days} days after it is created" : "A nyilvános hivatkozás érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
    "Set expiration date" : "Legyen lejárati idő",
    "Expiration" : "Lejárat",
    "Expiration date" : "Lejárati idő",
    "Link" : "Hivatkozás",
    "Edit" : "Szerkesztés",
    "Remove" : "Eltávolítás",
    "Choose a password for the public link" : "Válasszon egy jelszót a nyilvános linkhez",
    "Filename" : "Fájlnév",
    "Password" : "Jelszó",
    "Name" : "Név",
    "Allow editing" : "Szerkesztheti",
    "Save" : "Mentés",
    "Error while sending notification" : "Hiba történt az értesítő küldése közben",
    "Sending ..." : "Küldés ...",
    "Email sent" : "Az e-mailt elküldtük!",
    "Email link to person" : "Hivatkozás elküldése e-mail címre",
    "Send link via email" : "Hivatkozás küldése levélben",
    "Shared with you and the group {group} by {owner}" : "{owner} megosztotta Önnel és a(z) {group} csoporttal",
    "Shared with you by {owner}" : "{owner} megosztotta Önnel",
    "group" : "csoport",
    "remote" : "távoli",
    "notify by email" : "e-mail értesítés",
    "Unshare" : "Megosztás visszavonása",
    "can share" : "megoszthatja",
    "can edit" : "szerkesztheti",
    "create" : "létrehoz",
    "change" : "módosít",
    "delete" : "töröl",
    "access control" : "jogosultság",
    "Could not unshare" : "Nem sikerült visszavonni a megosztást",
    "Share details could not be loaded for this item." : "A megosztás részletei nem lehet betölteni ehhez az elemhez.",
    "No users or groups found for {search}" : "{search} keresésre nem található felhasználó vagy csoport",
    "No users found for {search}" : "{search} keresésre nem található felhasználó",
    "An error occurred. Please try again" : "Hiba történt. Kérjük, próbálja meg újra!",
    "{sharee} (group)" : "{sharee} (csoport)",
    "{sharee} (at {server})" : "{sharee} ({server} szerveren)",
    "{sharee} (remote)" : "{sharee} (távoli)",
    "Share" : "Megosztás",
    "Resharing is not allowed" : "Ezt az állományt csak a tulajdonosa oszthatja meg másokkal",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Megosztás más ownCloud szerverekkel, a következő formátum használatával felhasználó@példa.hu/owncloud",
    "Share with users…" : "Megosztás felhasználókkal",
    "Share with users, groups or remote users…" : "Megosztás felhasználókkal, csoportokkal vagy távoli felhasználókkal...",
    "Share with users or groups…" : "Megosztás felhasználókkal vagy csoportokkal...",
    "Share with users or remote users…" : "Megosztás felhasználókkal vagy távoli felhasználókkal...",
    "Error removing share" : "Hiba a megosztás törlésekor",
    "Warning" : "Figyelmeztetés",
    "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
    "invisible" : "láthatatlan",
    "({scope})" : "({scope})",
    "Delete" : "Törlés",
    "Rename" : "Átnevezés",
    "Collaborative tags" : "Címke hozzárendelése",
    "The object type is not specified." : "Az objektum típusa nincs megadva.",
    "Enter new" : "Új beírása",
    "Add" : "Hozzáadás",
    "Edit tags" : "Címkék szerkesztése",
    "Error loading dialog template: {error}" : "Hiba a párbeszédpanel-sablon betöltésekor: {error}",
    "No tags selected for deletion." : "Nincs törlésre kijelölt címke.",
    "unknown text" : "ismeretlen szöveg",
    "Hello world!" : "Üdv, Világ!",
    "sunny" : "napos",
    "Hello {name}, the weather is {weather}" : "Üdv {name}, {weather} időnk van",
    "Hello {name}" : "Üdv {name}!",
    "new" : "új",
    "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása néhány környezetben lehet, hogy megszakítja a folyamatot.",
    "Updating to {version}" : "Frissítés erre a verzióra: {version}",
    "An error occurred." : "Hiba történt.",
    "Please reload the page." : "Kérjük frissítse az oldalt!",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a fórumunkat</a> a probléma lefedéséért.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "A frissítés nem sikerült. Kérem értesítse erről a problémáról az <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud közösséget</a>.",
    "The update was successful. There were warnings." : "A frissítés sikerült. Figyelmeztetések találhatók.",
    "The update was successful. Redirecting you to ownCloud now." : "A frissítés sikeres volt. Visszairányítjuk az ownCloud szolgáltatáshoz.",
    "Searching other places" : "Keresés más helyeken",
    "No search results in other folders" : "Nincs keresési eredmény a másik könyvtárakban",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} keresési eredmény egy másik könyvtárban","{count} keresési eredmény más könyvtárakban"],
    "Personal" : "Személyes",
    "Users" : "Felhasználók",
    "Apps" : "Alkalmazások",
    "Admin" : "Adminsztráció",
    "Help" : "Súgó",
    "Access forbidden" : "A hozzáférés nem engedélyezett",
    "File not found" : "Fájl nem található",
    "The specified document has not been found on the server." : "A meghatározott dokumentum nem található a szerveren.",
    "You can click here to return to %s." : "Ide kattintva visszatérhet ide: %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Üdvözöljük!\n\nÉrtesítjük, hogy %s megosztotta Önnel a következőt: %s.\nItt nézheti meg: %s\n\n",
    "The share will expire on %s." : "A megosztás lejár ekkor: %s.",
    "Cheers!" : "Üdv.",
    "Internal Server Error" : "Belső szerver hiba",
    "The server encountered an internal error and was unable to complete your request." : "A szerver belső hibával találkozott és nem tudja teljesíteni a kérést.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Kérjük keresse fel a szerver rendszergazdáját, ha ez a hiba ismételten, többször előfordulna. Kérjük, mellékelje a technikai részleteket a lenti jelentésbe.",
    "More details can be found in the server log." : "További részletek a szerver naplóban találhatók.",
    "Technical details" : "Technikai adatok",
    "Remote Address: %s" : "Távoli cím: %s",
    "Request ID: %s" : "Kérelem azonosító: %s",
    "Type: %s" : "Típus: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Üzenet: %s",
    "File: %s" : "Fájl: %s",
    "Line: %s" : "Sor: %s",
    "Trace" : "Lekövetés",
    "Create an <strong>admin account</strong>" : "<strong>Rendszergazdai fiók</strong> létrehozása",
    "Username" : "Felhasználónév",
    "Storage & database" : "Tárhely és adatbázis",
    "Data folder" : "Adatkönyvtár",
    "Configure the database" : "Adatbázis konfigurálása",
    "Only %s is available." : "Csak %s érhető el.",
    "Install and activate additional PHP modules to choose other database types." : "Telepítse és aktiválja a bővített PHP modulokat, hogy tudjon más adatbázis típust is kiválasztani.",
    "For more details check out the documentation." : "További részletekért kérjük ellenőrizze a dokumentációt.",
    "Database user" : "Adatbázis felhasználónév",
    "Database password" : "Adatbázis jelszó",
    "Database name" : "Az adatbázis neve",
    "Database tablespace" : "Az adatbázis táblázattér (tablespace)",
    "Database host" : "Adatbázis szerver",
    "Performance warning" : "Teljesítménybeli figyelmeztetés",
    "SQLite will be used as database." : "SQLite lesz adatbázisként használva.",
    "For larger installations we recommend to choose a different database backend." : "Nagyobb telepítésekhez ajánlott egy másik adatbázis háttérkiszolgáló használata.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Amikor az asztali klienset használja fálj szinkronizációra, akkor az SQLite használata nem ajánlott.",
    "Finish setup" : "A beállítások befejezése",
    "Finishing …" : "Befejezés ...",
    "Need help?" : "Segítségre van szüksége?",
    "See the documentation" : "Nézze meg a dokumentációt",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Üdvözöljük!<br /><br />\n\nÉrtesítjük, hogy %s megosztotta Önnel a következőt: <strong>%s</strong><br />\n<a href=\"%s\">Itt nézheti meg.</a><br /><br />",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Az alkalmazás megfelelő működéséhez JavaScript szükséges. Kérjük, {linkstart}engedélyezze a JavaScript-et{linkend} és frissítse a lapot.",
    "Log out" : "Kijelentkezés",
    "Search" : "Keresés",
    "Server side authentication failed!" : "A szerveroldali hitelesítés sikertelen!",
    "Please contact your administrator." : "Kérjük, lépjen kapcsolatba a rendszergazdával.",
    "An internal error occurred." : "Belső hiba történt.",
    "Please try again or contact your administrator." : "Kérjük, próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
    "Username or email" : "Felhasználói név vagy e-mail cím",
    "Log in" : "Bejelentkezés",
    "Wrong password. Reset it?" : "Hibás jelszó. Visszaállítja?",
    "Wrong password." : "Hibás jelszó.",
    "Stay logged in" : "Maradjon bejelentkezve",
    "Alternative Logins" : "Alternatív bejelentkezés",
    "Use the following link to reset your password: {link}" : "Használja ezt a linket a jelszó ismételt beállításához: {link}",
    "New password" : "Új jelszó",
    "New Password" : "Új jelszó",
    "Reset password" : "Jelszó-visszaállítás",
    "This ownCloud instance is currently in single user mode." : "Ez az ownCloud szolgáltatás jelenleg egyfelhasználós üzemmódban működik.",
    "This means only administrators can use the instance." : "Ez azt jelenti, hogy csak az adminisztrátor használhatja ezt a példányt",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ha ez az üzenet ismételten vagy indokolatlanul megjelenik, akkor keresse fel a rendszergazdáját!",
    "Thank you for your patience." : "Köszönjük a türelmét!",
    "You are accessing the server from an untrusted domain." : "A kiszolgálót nem megbízható domain névvel éri el.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kérjük keresse fel a rendszergazdát! Ha ennek a telepítésnek Ön a rendszergazdája, akkor állítsa be a config/config.php állományban a \"trusted_domain\" paramétert! A config/config.sample.php állományban talál példát a beállításra.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "A beállításoktól függően, rendszergazdaként lehetséges, hogy az alábbi gombot is használhatja a domain név megbízhatóvá tételéhez.",
    "Add \"%s\" as trusted domain" : "Adjuk hozzá „%s”-t a megbízható domain nevekhez!",
    "App update required" : "Alkalmazás frissítése szükséges",
    "%s will be updated to version %s" : "%s frissítve lesz erre a verzióra: %s",
    "These apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
    "The theme %s has been disabled." : "%s téma letiltásra került.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Kérjük, gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatmappa tartalmát, mielőtt folytatja.",
    "Start update" : "A frissítés megkezdése",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Nagyobb telepítések esetén úgy kerülhetők el az időtúllépések, hogy inkább a következő parancsot adja ki a telepítési alkönyvtárban:",
    "Detailed logs" : "Részletezett naplók",
    "Update needed" : "Frissítés szükséges",
    "Please use the command line updater because you have a big instance." : "Kérjük, a frissítéshez a parancssort használja, mert nagyobb frissítést készül telepíteni.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Segítségért keresse fel a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentációt</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s folyamat éppen karbantartó üzemmódban van, ami eltarthat egy darabig.",
    "This page will refresh itself when the %s instance is available again." : "Ez az oldal frissíteni fogja magát amint a(z) %s példány ismét elérhető.",
    "Could not reset password because the token is invalid" : "Nem sikerült a jelszót visszaállítani, mert a token érvénytelen",
    "Could not reset password because the token expired" : "Nem sikerült a jelszót visszaállítani, mert a token lejárt",
    "Could not reset password because the token does not match" : "Nem sikerült a jelszót visszaállítani, mert a token nem egyezik",
    "Expiration date is required" : "A lejárat dátuma szükséges",
    "Remove link" : "Hivatkozás eltávolítása",
    "Create public link" : "Publikus hivatkozás létrehozása",
    "Copy to clipboard" : "Másold a vágólapra",
    "There are currently no link shares, you can create one" : "Jelenleg nincs egy hivatkozás sem megosztva, létrehozhatsz egyet",
    "Anyone with the link has access to the file/folder" : "Bárki a hivatkozással hozzáférhet a fájlhoz/mappához",
    "Password required" : "Jelszó szükséges",
    "Remove password" : "Jelszó eltávolítása",
    "User and Groups" : "Felhasználó és Csoportok",
    "Public Links" : "Publikus Hivatkozások",
    "restricted" : "korlátozott",
    "Delete {link}" : "Törlés {link}",
    "Share to Twitter. Opens in a new window." : "Megosztás Twitter-en. Új ablakban jelenik meg.",
    "Menu" : "Menü",
    "Read only" : "Csak olvasható",
    "Read & Write" : "Írás és olvasás",
    "Email notification not sent" : "E-mail értesítést nem küldtünk",
    "You took too long to login, please try again now" : "Túl sokáig tartott belépni, próbáld újra",
    "Password changed successfully" : "A jelszó sikeresen megváltozott",
    "Social share" : "Közösségi megosztás",
    "Cancel login" : "Bejelentkezés megszakítása",
    "An error occurred while verifying the token" : "Egy hiba merült fel a token érvényesítése közben",
    "Error adding {addItem}: {addItem} already exists" : "Hiba történt egy {addItem} hozzáadása esetén: az {addItem} már létezik",
    "federated" : "egyesített",
    "Two-step verification" : "Kétlépcsős azonosítás",
    "Link name" : "Link neve",
    "%s password changed successfully" : "%s jelszó sikeresen megváltozott",
    "{fileName} link" : "{fileName} hivatkozás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "Használd a ⌘-C másoláshoz.",
    "Press Ctrl-C to copy." : "Használd a Ctrl+C másoláshoz.",
    "Edit link share: {name}" : "Megosztási hivatkozás szerkesztése: {name}",
    "Create link share: {name}" : "Megosztási hivatkozás létrehozása: {name}",
    "Share to Facebook. Opens in a new window." : "Megosztás Facebook-on. Új ablakban jelenik meg.",
    "Share to Diaspora. Opens in a new window." : "Megosztás a Diaspora-n. Új ablakban jelenik meg.",
    "Share to Google+. Opens in a new window." : "Megosztás Google+ -on. Új ablakban jelenik meg.",
    "Share via email. Opens your mail client." : "Megosztás E-mailben. A levelező kliensedben jelenik meg.",
    "Owner: {owner}" : "Tulajdonos: {owner}",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Határozd meg a port számát a hosztnév mellett (pl.: localhost: 5432).",
    "Email notification was sent!" : "E-mail értesítést küldött!",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Kérjük, lépjen kapcsolatba a szerver rendszergazdájával, ha ez a hiba többször megjelenik újra, és tartalmazza az alábbi technikai részleteket a jelentésben.",
    "You are trying to access a private link. Please log in first." : "Egy privát hivatkozáshoz próbál hozzáférni. Kérjük, elsőként jelentkezzen be.",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Úgy néz ki, hogy a kiszolgáló talán sok fájlt és/vagy felhasználót szolgál ki. Ahhoz, hogy a frissítés simán végbemenjen, kérjük, hogy használja a parancssor-ból a frissítőt  (occ upgrade). ",
    "{sharee} (federated)" : "{sharee} (federated)",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "A kiterjesztett biztonság engedélyezve lett a fiókján. Kérjük a hitelesítéshez használjon egy második faktort.",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Az automatikus frissítés ki van kapcsolva a config.php -ban. A frissítéshez, használja a parancssori frissítőt (occ upgrade).",
    "Please authenticate using the selected factor." : "Kérjük a bejelentkezéshez használja a kiválasztott faktort.",
    "Sending" : "Küldés",
    "Imprint" : "Impresszum",
    "Couldn't send mail to following recipient(s): %s " : "Email küldese sikertelen a következő(k)nek: %s",
    "Choose an expiration date" : "Lejárati dátum választása",
    "Choose a password" : "Válasszon jelszót",
    "Send copy to self" : "Másolatküldés önmagának",
    "Add personal message" : "Személyes üzenet hozzáadása",
    "Upload only" : "Csak feltöltés",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Fájlok fogadása többszörös fogadóktól a mappa tartalmának felfedése nélkül",
    "Download / View" : "Letöltés / Megjelenítés",
    "Recipients can view or download contents." : "Fogadók letölthetnek és megjeleníthetnek tartalmakat.",
    "Download / View / Upload" : "Letöltés / Megjelenítés / Feltöltés",
    "Recipients can view, download, edit, delete and upload contents." : "Fogadók megjeleníthetnek, letölthetnek, módosíthatnak, törölhetnek és feltölthetnek tartalmakat.",
    "An error occured while sending email" : "Hiba az email küldése során",
    "E-Mail sent" : "Email elküldve",
    "Personal note from the sender: %s." : "Személyes megjegyzés %s küldőnek.",
    "Privacy Policy" : "Adatvédelmi szabályzat"
},
"nplurals=2; plural=(n != 1);");
